
import React, { useState } from "react";
import CityTime from "./CityTime";

export default function ClockDashboard() {
  const [cities, setCities] = useState([
    { name: "New York", timezone: "America/New_York" },
    { name: "India", timezone: "Asia/Kolkata" },
    { name: "London", timezone: "Europe/London" },
    { name: "Tokyo", timezone: "Asia/Tokyo" },
    { name: "Milano", timezone: "Europe/Rome" },
  ]);

  const [newCity, setNewCity] = useState({ name: "", timezone: "" });

  const addCity = () => {
    if (newCity.name && newCity.timezone) {
      setCities((prevCities) => [...prevCities, newCity]);
      setNewCity({ name: "", timezone: "" });
    }
  };

  const removeCity = (index) => {
    setCities((prevCities) => prevCities.filter((_, i) => i !== index));
  };

  return (
    <div className="world-clock">
      <h1>Clock Dashboard</h1>

      <div className="add-city">
        <input
          type="text"
          placeholder="City Name"
          value={newCity.name}
          onChange={(e) => setNewCity({ ...newCity, name: e.target.value })}
        />
        <input
          type="text"
          placeholder="Timezone (e.g., Asia/Kolkata)"
          value={newCity.timezone}
          onChange={(e) => setNewCity({ ...newCity, timezone: e.target.value })}
        />
        <button onClick={addCity}>Add City</button>
      </div>

      <ul className="cities">
        {cities.map((city, index) => (
          <li key={index} className="city-item">
            <CityTime city={city} />
            <button className="remove-btn" onClick={() => removeCity(index)}>
              Remove
            </button>
          </li>
        ))}
      </ul>
    </div>
  );
}
